@@ -552,14 +552,14 @@ def read_inps_dict2geometry_dict_object(iDict):
     return geomRadarObj, geomGeoObj
 
 
-def update_object(outFile, inObj, box, updateMode=True):
+def update_object(outFile, inObj, box, updateMode=True, xstep=1, ystep=1):
     """Do not write h5 file if: 1) h5 exists and readable,
                                 2) it contains all date12 from ifgramStackDict,
                                             or all datasets from geometryDict"""
     write_flag = True
     if updateMode and ut.run_or_skip(outFile, check_readable=True) == 'skip':
         if inObj.name == 'ifgramStack':
-            in_size = inObj.get_size(box=box)[1:]
+            in_size = inObj.get_size(box=box, xstep=xstep, ystep=ystep)[1:]
             in_date12_list = inObj.get_date12_list()
 
             outObj = ifgramStack(outFile)
@@ -572,13 +572,19 @@ def update_object(outFile, inObj, box, updateMode=True):
                 write_flag = False
 
         elif inObj.name == 'geometry':
+            in_size = inObj.get_size(box=box, xstep=xstep, ystep=ystep)
+            in_dset_list = inObj.get_dataset_list()
+
             outObj = geometry(outFile)
             outObj.open(print_msg=False)
-            if (outObj.get_size() == inObj.get_size(box=box)
-                    and all(i in outObj.datasetNames for i in inObj.get_dataset_list())):
+            out_size = outObj.get_size()
+            out_dset_list = outObj.datasetNames
+
+            if out_size == in_size and set(in_dset_list).issubset(set(out_dset_list)):
                 print(('All datasets exists in file {} with same size as required,'
                        ' no need to re-load.'.format(os.path.basename(outFile))))
                 write_flag = False
+
     return write_flag
 
 
@@ -613,12 +619,15 @@ def prepare_metadata(iDict):
         from mintpy import prep_isce
         from mintpy.utils.isce_utils import get_processor
 
+        # metadata
         meta_files = sorted(glob.glob(iDict['mintpy.load.metaFile']))
-        if len(meta_files) < 1:
+        if len(meta_files) > 0:
+            meta_file = meta_files[0]
+        else:
             warnings.warn('No input metadata file found: {}'.format(iDict['mintpy.load.metaFile']))
+            meta_file = 'auto'
 
-        # metadata and auxliary data
-        meta_file = meta_files[0]
+        # auxliary data
         baseline_dir = iDict['mintpy.load.baselineDir']
         geom_dir = os.path.dirname(iDict['mintpy.load.demFile'])
 
@@ -712,6 +721,7 @@ def print_write_setting(iDict):
     print('-'*50)
     print('updateMode : {}'.format(updateMode))
     print('compression: {}'.format(comp))
+    print('x/ystep: {}/{}'.format(iDict['xstep'], iDict['ystep']))
 
     # box
     box = iDict['box']
@@ -721,26 +731,23 @@ def print_write_setting(iDict):
     else:
         boxGeo = box
 
-    # step
-    xyStep = (iDict['xstep'], iDict['ystep'])
-    if not iDict.get('geocoded', False):
-        xyStepGeo = (1, 1)
-    else:
-        xyStepGeo = xyStep
-    print('x/ystep: {}/{}'.format(xyStep[0], xyStep[1]))
-
-    return updateMode, comp, box, boxGeo, xyStep, xyStepGeo
+    return updateMode, comp, box, boxGeo
 
 
 def get_extra_metadata(iDict):
-    """Extra metadata to be written into stack file"""
+    """Extra metadata with key names in MACRO_CASE to be written into stack file.
+    E.g.: PROJECT_NAME, PLATFORM, ORBIT_DIRECTION, SUBSET_X/YMIN, etc.
+    """
     extraDict = {}
-    for key in ['PROJECT_NAME', 'PLATFORM']:
-        if iDict[key]:
-            extraDict[key] = iDict[key]
-    for key in ['SUBSET_XMIN', 'SUBSET_YMIN']:
-        if key in iDict.keys():
-            extraDict[key] = iDict[key]
+    # all keys in MACRO_CASE
+    upper_keys = [i for i in iDict.keys() if i.isupper()]
+    for key in upper_keys:
+        value  = iDict[key]
+        if key in ['PROJECT_NAME', 'PLATFORM']:
+            if value:
+                extraDict[key] = value
+        else:
+            extraDict[key] = value
     return extraDict
 
 
@@ -767,39 +774,48 @@ def main(iargs=None):
     geomRadarObj, geomGeoObj = read_inps_dict2geometry_dict_object(iDict)
 
     # prepare write
-    updateMode, comp, box, boxGeo, xyStep, xyStepGeo = print_write_setting(iDict)
+    updateMode, comp, box, boxGeo = print_write_setting(iDict)
     if any([stackObj, geomRadarObj, geomGeoObj]) and not os.path.isdir(inps.outdir):
         os.makedirs(inps.outdir)
         print('create directory: {}'.format(inps.outdir))
 
     # write
-    if stackObj and update_object(inps.outfile[0], stackObj, box, updateMode=updateMode):
+    if stackObj and update_object(inps.outfile[0], stackObj, box,
+                                  updateMode=updateMode,
+                                  xstep=iDict['xstep'],
+                                  ystep=iDict['ystep']):
         print('-'*50)
         stackObj.write2hdf5(outputFile=inps.outfile[0],
                             access_mode='w',
                             box=box,
-                            xstep=xyStep[0],
-                            ystep=xyStep[1],
+                            xstep=iDict['xstep'],
+                            ystep=iDict['ystep'],
                             compression=comp,
                             extra_metadata=extraDict)
 
-    if geomRadarObj and update_object(inps.outfile[1], geomRadarObj, box, updateMode=updateMode):
+    if geomRadarObj and update_object(inps.outfile[1], geomRadarObj, box,
+                                      updateMode=updateMode,
+                                      xstep=iDict['xstep'],
+                                      ystep=iDict['ystep']):
         print('-'*50)
         geomRadarObj.write2hdf5(outputFile=inps.outfile[1],
                                 access_mode='w',
                                 box=box,
-                                xstep=xyStep[0],
-                                ystep=xyStep[1],
+                                xstep=iDict['xstep'],
+                                ystep=iDict['ystep'],
                                 compression='lzf',
                                 extra_metadata=extraDict)
 
-    if geomGeoObj and update_object(inps.outfile[2], geomGeoObj, boxGeo, updateMode=updateMode):
+    if geomGeoObj and update_object(inps.outfile[2], geomGeoObj, boxGeo,
+                                    updateMode=updateMode,
+                                    xstep=iDict['xstep'],
+                                    ystep=iDict['ystep']):
         print('-'*50)
         geomGeoObj.write2hdf5(outputFile=inps.outfile[2],
                               access_mode='w',
                               box=boxGeo,
-                              xstep=xyStepGeo[0],
-                              ystep=xyStepGeo[1],
+                              xstep=iDict['xstep'],
+                              ystep=iDict['ystep'],
                               compression='lzf')
 
     # time info
