@@ -321,8 +321,8 @@ class TimeSeriesAnalysis:
                                              check_readable=False,
                                              print_msg=False) == 'run':
                     shutil.copy2(tfile, backup_dir)
-                    print('copy {} to {} directory for backup.'.format(os.path.basename(tfile),
-                                                                       os.path.basename(backup_dir)))
+                    print('copy {} to {:<8} directory for backup.'.format(os.path.basename(tfile),
+                                                                          os.path.basename(backup_dir)))
 
         # 3) read default template file
         print('read default template file:', self.templateFile)
@@ -960,9 +960,7 @@ class TimeSeriesAnalysis:
 
                 geom_file, lookup_file = ut.check_loaded_dataset(self.workDir, print_msg=False)[2:4]
                 in_files = [geom_file, 'temporalCoherence.h5', 'avgSpatialCoh.h5', ts_file, 'velocity.h5']
-                iargs = ['-l', lookup_file, '-t', self.templateFile, '--outdir', out_dir, '--update']
-                for in_file in in_files:
-                    iargs += [in_file]
+                iargs = in_files + ['-l', lookup_file, '-t', self.templateFile, '--outdir', out_dir, '--update']
                 print('\ngeocode.py', ' '.join(iargs))
                 mintpy.geocode.main(iargs)
 
