@@ -86,9 +86,9 @@ def create_parser():
     # reference in time and space
     # for input file without reference info, e.g. ERA5.h5
     parser.add_argument('--ref-yx', dest='ref_yx', metavar=('Y', 'X'), type=int, nargs=2,
-                        help='Change referene point Y X for display')
+                        help='Change referene point Y X for estimation.')
     parser.add_argument('--ref-date', dest='ref_date', metavar='DATE',
-                        help='Change reference date for display')
+                        help='Change reference date for estimation.')
 
     # dates of interest
     date = parser.add_argument_group('dates of interest')
@@ -268,6 +268,17 @@ def read_date_info(inps):
     tsobj.open()
     inps.excludeDate = read_exclude_date(inps, tsobj.dateList)
 
+    # exclude dates without obs data [for offset time-series only for now]
+    if os.path.basename(inps.timeseries_file).startswith('timeseriesRg'):
+        date_list = timeseries(inps.timeseries_file).get_date_list()
+        data, atr = readfile.read(inps.timeseries_file)
+        flag = np.nansum(data, axis=(1,2)) == 0
+        flag[date_list.index(atr['REF_DATE'])] = 0
+        if np.sum(flag) > 0:
+            print('number of empty dates to exclude: {}'.format(np.sum(flag)))
+            inps.excludeDate += np.array(date_list)[flag].tolist()
+            inps.excludeDate = sorted(list(set(inps.excludeDate)))
+
     # Date used for estimation inps.dateList
     inps.dateList = [i for i in tsobj.dateList if i not in inps.excludeDate]
     inps.numDate = len(inps.dateList)
@@ -422,7 +433,7 @@ def run_timeseries2time_func(inps):
             ref_ind = inps.dateList.index(inps.ref_date)
             ts_data -= np.tile(ts_data[ref_ind, :, :], (ts_data.shape[0], 1, 1))
         if inps.ref_yx:
-            print('referencing to point (y, x): ({}, {})'.format(inps.ref_yx[0], inps.ref_yx[0]))
+            print('referencing to point (y, x): ({}, {})'.format(inps.ref_yx[0], inps.ref_yx[1]))
             ref_box = (inps.ref_yx[1], inps.ref_yx[0], inps.ref_yx[1]+1, inps.ref_yx[0]+1)
             ref_val = readfile.read(inps.timeseries_file, box=ref_box)[0]
             ts_data -= np.tile(ref_val.reshape(ts_data.shape[0], 1, 1), (1, ts_data.shape[1], ts_data.shape[2]))
