@@ -150,7 +150,7 @@ def cmd_line_parse(iargs=None):
     print(msg)
 
     ## weather_dir
-    # expand path for ~ and environmental variables in the path
+    # expand path for ~ and environment variables in the path
     inps.weather_dir = os.path.expanduser(inps.weather_dir)
     inps.weather_dir = os.path.expandvars(inps.weather_dir)
     # fallback value if WEATHER_DIR is not defined as environmental variable
@@ -163,7 +163,7 @@ def cmd_line_parse(iargs=None):
     for key in ['dis_file', 'geom_file']:
         fname = vars(inps)[key]
         if fname and not os.path.isfile(fname):
-            raise FileExistsError('input file not exist: {}'.format(fname))
+            raise FileNotFoundError('input file not exist: {}'.format(fname))
 
     ## required options (for date/time): --file OR --date-list
     if (not inps.dis_file 
@@ -339,7 +339,7 @@ def safe2date_time(safe_file, tropo_model):
             for second in seconds:
                 secondsOut.append(second)
         else:
-            print('\nUn-recognized CENTER_LINE_ UTC input!')
+            print('\nUn-recognized CENTER_LINE_UTC input!')
             return None
 
         return secondsOut
@@ -639,15 +639,17 @@ def calc_delay_timeseries(inps):
         inps.dem[:] = inps.custom_height
 
     if 'latitude' in geom_obj.datasetNames:
-        # for dataset in geo OR radar coord with lookup table in radar-coord (isce, doris)
+        # for lookup table in radar-coord (isce, doris)
         inps.lat = geom_obj.read(datasetName='latitude')
         inps.lon = geom_obj.read(datasetName='longitude')
+
     elif 'Y_FIRST' in geom_obj.metadata:
-        # for geo-coded dataset (gamma, roipac)
+        # for lookup table in geo-coded (gamma, roipac) and obs. in geo-coord
         inps.lat, inps.lon = ut.get_lat_lon(geom_obj.metadata)
+
     else:
-        # for radar-coded dataset (gamma, roipac)
-        inps.lat, inps.lon = ut.get_lat_lon_rdc(geom_obj.metadata)
+        # for lookup table in geo-coded (gamma, roipac) and obs. in radar-coord
+        inps.lat, inps.lon = ut.get_lat_lon_rdc(inps.atr)
 
 
     ## 2. prepare output file
