@@ -233,8 +233,11 @@ def auto_figure_title(fname, datasetNames=[], inps_dict=None):
     if inps_dict.get('wrap', False):
         fig_title += '_wrap'
         wrap_range = inps_dict.get('wrap_range', [-1.*np.pi, np.pi])
-        if (wrap_range[1] - wrap_range[0]) != 2*np.pi:
-            fig_title += str(wrap_range[1] - wrap_range[0])
+        wrap_range = wrap_range[1] - wrap_range[0]
+        if wrap_range != 2*np.pi:
+            if wrap_range == int(wrap_range):
+                wrap_range = int(wrap_range)
+            fig_title += str(wrap_range)
 
     return fig_title
 
@@ -340,29 +343,35 @@ def auto_colormap_name(metadata, cmap_name=None, datasetName=None, print_msg=Tru
 def auto_adjust_colormap_lut_and_disp_limit(data, num_multilook=1, max_discrete_num_step=20, print_msg=True):
 
     # max step size / min step number for a uniform colormap
-    unique_values = np.unique(data[~np.isnan(data)])
+    unique_values = np.unique(data[~np.isnan(data) * np.isfinite(data)])
     min_val = np.min(unique_values).astype(float)
     max_val = np.max(unique_values).astype(float)
-    vstep = np.min(np.diff(unique_values)).astype(float)
-    min_num_step = int((max_val - min_val) / vstep + 1)
 
-    # use discrete colromap for data with uniform AND limited unique values
-    # e.g. unwrapError time-series
-    if min_num_step <= max_discrete_num_step:
-        cmap_lut = min_num_step
-        vlim = [min_val - vstep/2, max_val + vstep/2]
-
-        if print_msg:
-            msg = 'data has uniform and limited number ({} <= {})'.format(unique_values.size, max_discrete_num_step)
-            msg += ' of unique values --> discretize colormap'
-            print(msg)
+    if min_val == max_val:
+        cmap_lut = 256
+        vlim = [min_val, max_val]
 
     else:
-        from mintpy.multilook import multilook_data
-        data_mli = multilook_data(data, num_multilook, num_multilook)
+        vstep = np.min(np.abs(np.diff(unique_values))).astype(float)
+        min_num_step = int((max_val - min_val) / vstep + 1)
 
-        cmap_lut = 256
-        vlim = [np.nanmin(data_mli), np.nanmax(data_mli)]
+        # use discrete colromap for data with uniform AND limited unique values
+        # e.g. unwrapError time-series
+        if min_num_step <= max_discrete_num_step:
+            cmap_lut = min_num_step
+            vlim = [min_val - vstep/2, max_val + vstep/2]
+
+            if print_msg:
+                msg = 'data has uniform and limited number ({} <= {})'.format(unique_values.size, max_discrete_num_step)
+                msg += ' of unique values --> discretize colormap'
+                print(msg)
+
+        else:
+            from mintpy.multilook import multilook_data
+            data_mli = multilook_data(data, num_multilook, num_multilook)
+
+            cmap_lut = 256
+            vlim = [np.nanmin(data_mli), np.nanmax(data_mli)]
 
     return cmap_lut, vlim
 
@@ -1162,7 +1171,7 @@ def plot_colorbar(inps, im, cax):
         cbar.set_label(inps.cbar_label, fontsize=inps.font_size, color=inps.font_color)
     elif inps.disp_unit != '1':
         cbar.set_label(inps.disp_unit,  fontsize=inps.font_size, color=inps.font_color)
-        
+
     return inps, cbar
 
 
@@ -1346,23 +1355,25 @@ def read_mask(fname, mask_file=None, datasetName=None, box=None, print_msg=True)
     atr = readfile.read_attribute(fname)
     k = atr['FILE_TYPE']
 
-    # default mask file:
+    # default mask file
     if (not mask_file
             and k in ['velocity', 'timeseries']
-            and 'masked' not in fname):
+            and 'msk' not in fname):
 
-        mask_file = 'maskTempCoh.h5'
-        if 'PhaseVelocity' in fname:
-            mask_file = None #'maskSpatialCoh.h5'
+        for mask_file in ['maskTempCoh.h5', 'maskResInv.h5']:
+            if 'PhaseVelocity' in fname:
+                mask_file = None #'maskSpatialCoh.h5'
 
-        # check coordinate
-        if os.path.basename(fname).startswith('geo_'):
-            mask_file = 'geo_{}'.format(mask_file)
+            # check coordinate
+            if os.path.basename(fname).startswith('geo_'):
+                mask_file = 'geo_{}'.format(mask_file)
 
-        # absolute path and file existence
-        mask_file = os.path.join(os.path.dirname(fname), str(mask_file))
-        if not os.path.isfile(mask_file):
-            mask_file = None
+            # absolute path and file existence
+            mask_file = os.path.join(os.path.dirname(fname), str(mask_file))
+            if os.path.isfile(mask_file):
+                break
+            else:
+                mask_file = None
 
     # Read mask file if inputed
     msk = None
@@ -1461,8 +1472,7 @@ def auto_lalo_sequence(geo_box, lalo_step=None, lalo_max_num=4, step_candidate=[
 
 
 def draw_lalo_label(geo_box, ax=None, lalo_step=None, lalo_loc=[1, 0, 0, 1], lalo_max_num=4,
-                    font_size=12, xoffset=None, yoffset=None, yrotate='horizontal',
-                    projection=ccrs.PlateCarree(), print_msg=True):
+                    font_size=12, xoffset=None, yoffset=None, projection=ccrs.PlateCarree(), print_msg=True):
     """Auto draw lat/lon label/tick based on coverage from geo_box
     Parameters: geo_box   : 4-tuple of float, (W, N, E, S) in degree
                 ax        : CartoPy axes.
