@@ -135,7 +135,7 @@ def cmd_line_parse(iargs=None):
     for key in ['file','dem_file','mask_file','pts_file']:
         fname = vars(inps)[key]
         if fname not in [None, 'no'] and not os.path.isfile(fname):
-            raise FileExistsError('input {} file {} NOT exist!'.format(key, fname))
+            raise FileNotFoundError('input {} file {} NOT exist!'.format(key, fname))
 
     # --exclude
     if inps.exDsetList:
@@ -503,7 +503,6 @@ def plot_slice(ax, data, metadata, inps=None):
                                    lalo_loc=inps.lalo_loc,
                                    lalo_max_num=inps.lalo_max_num,
                                    font_size=inps.font_size,
-                                   yrotate=inps.lat_label_direction,
                                    projection=inps.proj_obj,
                                    print_msg=inps.print_msg)
             else:
@@ -544,12 +543,14 @@ def plot_slice(ax, data, metadata, inps=None):
                         msg += ', v=[]'
                     else:
                         msg += ', v={:.3f}'.format(v)
+                    # DEM
                     if inps.dem_file:
                         dem_col = coord_dem.lalo2yx(x, coord_type='lon') - dem_pix_box[0]
                         dem_row = coord_dem.lalo2yx(y, coord_type='lat') - dem_pix_box[1]
                         if 0 <= dem_col < dem_wid and 0 <= dem_row < dem_len:
                             h = dem[dem_row, dem_col]
                             msg += ', h={:.0f}'.format(h)
+                    # x/y
                     msg += ', x={:.0f}, y={:.0f}'.format(col+inps.pix_box[0],
                                                          row+inps.pix_box[1])
                 return msg
@@ -591,7 +592,11 @@ def plot_slice(ax, data, metadata, inps=None):
                 row = int(np.rint((y - inps.geo_box[1]) / float(metadata['Y_STEP'])))
                 if 0 <= col < num_col and 0 <= row < num_row:
                     v = data[row, col]
-                    msg += ', v={:.3f}'.format(v)
+                    if np.isnan(v) or np.ma.is_masked(v):
+                        msg += ', v=[]'
+                    else:
+                        msg += ', v={:.3f}'.format(v)
+                    # DEM
                     if inps.dem_file:
                         h = dem[row, col]
                         msg += ', h={:.0f} m'.format(h)
@@ -663,7 +668,11 @@ def plot_slice(ax, data, metadata, inps=None):
             row = int(np.rint(y - inps.pix_box[1]))
             if 0 <= col < num_col and 0 <= row < num_row:
                 v = data[row, col]
-                msg += ', v={:.3f}'.format(v)
+                if np.isnan(v) or np.ma.is_masked(v):
+                    msg += ', v=[]'
+                else:
+                    msg += ', v={:.3f}'.format(v)
+                # DEM
                 if inps.dem_file:
                     h = dem[row, col]
                     msg += ', h={:.0f} m'.format(h)
@@ -905,7 +914,7 @@ def update_figure_setting(inps):
 
         # Row/Column number
         if (inps.fig_row_num == 1 and inps.fig_col_num == 1
-                and all(i not in sys.argv for i in ['--nrows', '--ncols'])):
+                and all(i not in inps.argv for i in ['--nrows', '--ncols'])):
             # calculate row and col number based on input info
             data_shape = [length*1.1, width]
             fig_size4plot = [inps.fig_size[0]*0.95, inps.fig_size[1]]
@@ -1045,7 +1054,7 @@ def read_data4figure(i_start, i_end, inps, metadata):
     # update display min/max
     inps.dlim = [np.nanmin(data), np.nanmax(data)]
     if (same_unit4all_subplots
-            and all(arg not in sys.argv for arg in ['-v', '--vlim', '--wrap'])
+            and all(arg not in inps.argv for arg in ['-v', '--vlim', '--wrap'])
             and not (inps.dsetFamilyList[0].startswith('unwrap') and not inps.file_ref_yx)
             and inps.dsetFamilyList[0] not in ['bperp']):
         inps.cmap_lut, inps.vlim = pp.auto_adjust_colormap_lut_and_disp_limit(data,
@@ -1119,9 +1128,11 @@ def plot_subplot4figure(i, inps, ax, data, metadata):
                 title_str = title_str.split('-')[1]
 
             num_subplot = inps.fig_row_num * inps.fig_col_num
-            if num_subplot <= 20:
+            if num_subplot <= 6:
+                subplot_title = title_str
+            elif 6 < num_subplot <= 20:
                 subplot_title = '{}\n{}'.format(i, title_str)
-            elif num_subplot <= 50:
+            elif 20 < num_subplot <= 50:
                 subplot_title = title_str.replace('_','\n').replace('-','\n')
             else:
                 subplot_title = '{}'.format(i)
@@ -1197,6 +1208,11 @@ def plot_figure(j, inps, metadata):
         im = plot_subplot4figure(i, inps, ax=ax,
                                  data=data[idx, :, :],
                                  metadata=metadata)
+
+        # colorbar for each subplot
+        if inps.disp_cbar and not inps.vlim:
+            fig.colorbar(im, ax=ax, pad=0.03, shrink=0.5, aspect=30, orientation='vertical')
+
         prog_bar.update(idx+1, suffix=inps.dset[i].split('/')[-1])
     prog_bar.close()
     del data
@@ -1218,10 +1234,13 @@ def plot_figure(j, inps, metadata):
         vprint('display range: {} {}'.format(inps.vlim, inps.disp_unit))
 
     # Colorbar
-    if not inps.vlim:
-        vprint('Note: different color scale for EACH subplot!')
-    else:
-        if inps.disp_cbar:
+    if inps.disp_cbar:
+        if not inps.vlim:
+            vprint('Note: different color scale for EACH subplot!')
+            vprint('Adjust figsize for the colorbar of each subplot.')
+            fig.set_size_inches(inps.fig_size[0] * 1.1,
+                                inps.fig_size[1])
+        else:
             cbar_length = 0.4
             if inps.fig_size[1] > 8.0:
                 cbar_length /= 2
@@ -1412,6 +1431,7 @@ class viewer():
 
     def configure(self):
         inps = cmd_line_parse(self.iargs)
+        inps.argv = list(self.iargs)
         inps, self.atr = read_input_file_info(inps)
         inps = update_inps_with_file_metadata(inps, self.atr)
 
